UseWidgetSize class
A data class holding the reactive size and the builder function.
size: ARefcontaining theSizeof the widget.builder: A function that you wrap around your widget to capture its size.
Constructors
-
UseWidgetSize(Ref<
Size?> size, Widget builder(Widget builder()))
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited